==> aws-cdk-scala-sqs_3-0.1.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"sqs","t":"sqs","d":"","k":"static"},
{"l":"io/burkard/cdk/services/sqs.html","n":"io.burkard.cdk.services.sqs","t":"package io.burkard.cdk.services.sqs","d":"io/burkard/cdk/services/sqs","k":"package"},
{"l":"io/burkard/cdk/services/sqs/CfnQueue$.html","n":"CfnQueue","t":"object CfnQueue","d":"io/burkard/cdk/services/sqs/CfnQueue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueue$.html","n":"apply","t":"def apply(internalResourceId: String, fifoThroughputLimit: Option[String], tags: Option[List[_ <: CfnTag]], messageRetentionPeriod: Option[Number], visibilityTimeout: Option[Number], deduplicationScope: Option[String], fifoQueue: Option[Boolean], kmsDataKeyReusePeriodSeconds: Option[Number], queueName: Option[String], kmsMasterKeyId: Option[String], maximumMessageSize: Option[Number], redriveAllowPolicy: Option[AnyRef], receiveMessageWaitTimeSeconds: Option[Number], contentBasedDeduplication: Option[Boolean], redrivePolicy: Option[AnyRef], delaySeconds: Option[Number])(implicit stackCtx: Stack): CfnQueue","d":"io/burkard/cdk/services/sqs/CfnQueue$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicy$.html","n":"CfnQueuePolicy","t":"object CfnQueuePolicy","d":"io/burkard/cdk/services/sqs/CfnQueuePolicy$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicy$.html","n":"apply","t":"def apply(internalResourceId: String, queues: Option[List[String]], policyDocument: Option[AnyRef])(implicit stackCtx: Stack): CfnQueuePolicy","d":"io/burkard/cdk/services/sqs/CfnQueuePolicy$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$.html","n":"CfnQueuePolicyProps","t":"object CfnQueuePolicyProps","d":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$.html","n":"apply","t":"def apply(queues: Option[List[String]], policyDocument: Option[AnyRef]): CfnQueuePolicyProps","d":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/CfnQueueProps$.html","n":"CfnQueueProps","t":"object CfnQueueProps","d":"io/burkard/cdk/services/sqs/CfnQueueProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueueProps$.html","n":"apply","t":"def apply(fifoThroughputLimit: Option[String], tags: Option[List[_ <: CfnTag]], messageRetentionPeriod: Option[Number], visibilityTimeout: Option[Number], deduplicationScope: Option[String], fifoQueue: Option[Boolean], kmsDataKeyReusePeriodSeconds: Option[Number], queueName: Option[String], kmsMasterKeyId: Option[String], maximumMessageSize: Option[Number], redriveAllowPolicy: Option[AnyRef], receiveMessageWaitTimeSeconds: Option[Number], contentBasedDeduplication: Option[Boolean], redrivePolicy: Option[AnyRef], delaySeconds: Option[Number]): CfnQueueProps","d":"io/burkard/cdk/services/sqs/CfnQueueProps$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/DeadLetterQueue$.html","n":"DeadLetterQueue","t":"object DeadLetterQueue","d":"io/burkard/cdk/services/sqs/DeadLetterQueue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/DeadLetterQueue$.html","n":"apply","t":"def apply(queue: Option[IQueue], maxReceiveCount: Option[Number]): DeadLetterQueue","d":"io/burkard/cdk/services/sqs/DeadLetterQueue$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope.html","n":"DeduplicationScope","t":"class DeduplicationScope(val underlying: DeduplicationScope) extends Product with Serializable","d":"io/burkard/cdk/services/sqs/DeduplicationScope","k":"class"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope.html","n":"underlying","t":"val underlying: DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope","k":"val"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$.html","n":"DeduplicationScope","t":"object DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$.html","n":"toAws","t":"def toAws(value: DeduplicationScope): DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$$MessageGroup$.html","n":"MessageGroup","t":"object MessageGroup extends DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$$MessageGroup$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$$Queue$.html","n":"Queue","t":"object Queue extends DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$$Queue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit.html","n":"FifoThroughputLimit","t":"class FifoThroughputLimit(val underlying: FifoThroughputLimit) extends Product with Serializable","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit","k":"class"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit.html","n":"underlying","t":"val underlying: FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit","k":"val"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$.html","n":"FifoThroughputLimit","t":"object FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$.html","n":"toAws","t":"def toAws(value: FifoThroughputLimit): FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerMessageGroupId$.html","n":"PerMessageGroupId","t":"object PerMessageGroupId extends FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerMessageGroupId$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerQueue$.html","n":"PerQueue","t":"object PerQueue extends FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerQueue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/Queue$.html","n":"Queue","t":"object Queue","d":"io/burkard/cdk/services/sqs/Queue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/Queue$.html","n":"apply","t":"def apply(internalResourceId: String, fifoThroughputLimit: Option[FifoThroughputLimit], visibilityTimeout: Option[Duration], maxMessageSizeBytes: Option[Number], deliveryDelay: Option[Duration], encryption: Option[QueueEncryption], queueName: Option[String], fifo: Option[Boolean], retentionPeriod: Option[Duration], deadLetterQueue: Option[DeadLetterQueue], deduplicationScope: Option[DeduplicationScope], encryptionMasterKey: Option[IKey], receiveMessageWaitTime: Option[Duration], contentBasedDeduplication: Option[Boolean], removalPolicy: Option[RemovalPolicy], dataKeyReuse: Option[Duration])(implicit stackCtx: Stack): Queue","d":"io/burkard/cdk/services/sqs/Queue$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueAttributes$.html","n":"QueueAttributes","t":"object QueueAttributes","d":"io/burkard/cdk/services/sqs/QueueAttributes$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueAttributes$.html","n":"apply","t":"def apply(queueUrl: Option[String], queueArn: Option[String], keyArn: Option[String], queueName: Option[String], fifo: Option[Boolean]): QueueAttributes","d":"io/burkard/cdk/services/sqs/QueueAttributes$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption.html","n":"QueueEncryption","t":"class QueueEncryption(val underlying: QueueEncryption) extends Product with Serializable","d":"io/burkard/cdk/services/sqs/QueueEncryption","k":"class"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption.html","n":"underlying","t":"val underlying: QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption","k":"val"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$.html","n":"QueueEncryption","t":"object QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$.html","n":"toAws","t":"def toAws(value: QueueEncryption): QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$$Kms$.html","n":"Kms","t":"object Kms extends QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$$Kms$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$$KmsManaged$.html","n":"KmsManaged","t":"object KmsManaged extends QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$$KmsManaged$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$$Unencrypted$.html","n":"Unencrypted","t":"object Unencrypted extends QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$$Unencrypted$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicy$.html","n":"QueuePolicy","t":"object QueuePolicy","d":"io/burkard/cdk/services/sqs/QueuePolicy$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicy$.html","n":"apply","t":"def apply(internalResourceId: String, queues: Option[List[_ <: IQueue]])(implicit stackCtx: Stack): QueuePolicy","d":"io/burkard/cdk/services/sqs/QueuePolicy$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicyProps$.html","n":"QueuePolicyProps","t":"object QueuePolicyProps","d":"io/burkard/cdk/services/sqs/QueuePolicyProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicyProps$.html","n":"apply","t":"def apply(queues: Option[List[_ <: IQueue]]): QueuePolicyProps","d":"io/burkard/cdk/services/sqs/QueuePolicyProps$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueProps$.html","n":"QueueProps","t":"object QueueProps","d":"io/burkard/cdk/services/sqs/QueueProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueProps$.html","n":"apply","t":"def apply(fifoThroughputLimit: Option[FifoThroughputLimit], visibilityTimeout: Option[Duration], maxMessageSizeBytes: Option[Number], deliveryDelay: Option[Duration], encryption: Option[QueueEncryption], queueName: Option[String], fifo: Option[Boolean], retentionPeriod: Option[Duration], deadLetterQueue: Option[DeadLetterQueue], deduplicationScope: Option[DeduplicationScope], encryptionMasterKey: Option[IKey], receiveMessageWaitTime: Option[Duration], contentBasedDeduplication: Option[Boolean], removalPolicy: Option[RemovalPolicy], dataKeyReuse: Option[Duration]): QueueProps","d":"io/burkard/cdk/services/sqs/QueueProps$","k":"def"},
{"l":"docs/index.html","n":"sqs","t":"sqs","d":"","k":"static"}];

==> aws-cdk-scala-sqs_3-0.1.7-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"sqs","t":"sqs","d":"","k":"static"},
{"l":"io/burkard/cdk/services/sqs.html","n":"io.burkard.cdk.services.sqs","t":"package io.burkard.cdk.services.sqs","d":"io/burkard/cdk/services/sqs","k":"package"},
{"l":"io/burkard/cdk/services/sqs/CfnQueue$.html","n":"CfnQueue","t":"object CfnQueue","d":"io/burkard/cdk/services/sqs/CfnQueue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueue$.html","n":"apply","t":"def apply(internalResourceId: String, fifoThroughputLimit: Option[String], tags: Option[List[_ <: CfnTag]], messageRetentionPeriod: Option[Number], visibilityTimeout: Option[Number], deduplicationScope: Option[String], fifoQueue: Option[Boolean], kmsDataKeyReusePeriodSeconds: Option[Number], queueName: Option[String], kmsMasterKeyId: Option[String], maximumMessageSize: Option[Number], redriveAllowPolicy: Option[AnyRef], receiveMessageWaitTimeSeconds: Option[Number], contentBasedDeduplication: Option[Boolean], redrivePolicy: Option[AnyRef], delaySeconds: Option[Number])(implicit stackCtx: Stack): CfnQueue","d":"io/burkard/cdk/services/sqs/CfnQueue$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicy$.html","n":"CfnQueuePolicy","t":"object CfnQueuePolicy","d":"io/burkard/cdk/services/sqs/CfnQueuePolicy$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicy$.html","n":"apply","t":"def apply(internalResourceId: String, queues: List[String], policyDocument: AnyRef)(implicit stackCtx: Stack): CfnQueuePolicy","d":"io/burkard/cdk/services/sqs/CfnQueuePolicy$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$.html","n":"CfnQueuePolicyProps","t":"object CfnQueuePolicyProps","d":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$.html","n":"apply","t":"def apply(queues: List[String], policyDocument: AnyRef): CfnQueuePolicyProps","d":"io/burkard/cdk/services/sqs/CfnQueuePolicyProps$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/CfnQueueProps$.html","n":"CfnQueueProps","t":"object CfnQueueProps","d":"io/burkard/cdk/services/sqs/CfnQueueProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/CfnQueueProps$.html","n":"apply","t":"def apply(fifoThroughputLimit: Option[String], tags: Option[List[_ <: CfnTag]], messageRetentionPeriod: Option[Number], visibilityTimeout: Option[Number], deduplicationScope: Option[String], fifoQueue: Option[Boolean], kmsDataKeyReusePeriodSeconds: Option[Number], queueName: Option[String], kmsMasterKeyId: Option[String], maximumMessageSize: Option[Number], redriveAllowPolicy: Option[AnyRef], receiveMessageWaitTimeSeconds: Option[Number], contentBasedDeduplication: Option[Boolean], redrivePolicy: Option[AnyRef], delaySeconds: Option[Number]): CfnQueueProps","d":"io/burkard/cdk/services/sqs/CfnQueueProps$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/DeadLetterQueue$.html","n":"DeadLetterQueue","t":"object DeadLetterQueue","d":"io/burkard/cdk/services/sqs/DeadLetterQueue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/DeadLetterQueue$.html","n":"apply","t":"def apply(queue: IQueue, maxReceiveCount: Number): DeadLetterQueue","d":"io/burkard/cdk/services/sqs/DeadLetterQueue$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope.html","n":"DeduplicationScope","t":"class DeduplicationScope(val underlying: DeduplicationScope) extends Product with Serializable","d":"io/burkard/cdk/services/sqs/DeduplicationScope","k":"class"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope.html","n":"underlying","t":"val underlying: DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope","k":"val"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$.html","n":"DeduplicationScope","t":"object DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$.html","n":"toAws","t":"def toAws(value: DeduplicationScope): DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$$MessageGroup$.html","n":"MessageGroup","t":"object MessageGroup extends DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$$MessageGroup$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/DeduplicationScope$$Queue$.html","n":"Queue","t":"object Queue extends DeduplicationScope","d":"io/burkard/cdk/services/sqs/DeduplicationScope$$Queue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit.html","n":"FifoThroughputLimit","t":"class FifoThroughputLimit(val underlying: FifoThroughputLimit) extends Product with Serializable","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit","k":"class"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit.html","n":"underlying","t":"val underlying: FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit","k":"val"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$.html","n":"FifoThroughputLimit","t":"object FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$.html","n":"toAws","t":"def toAws(value: FifoThroughputLimit): FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerMessageGroupId$.html","n":"PerMessageGroupId","t":"object PerMessageGroupId extends FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerMessageGroupId$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerQueue$.html","n":"PerQueue","t":"object PerQueue extends FifoThroughputLimit","d":"io/burkard/cdk/services/sqs/FifoThroughputLimit$$PerQueue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/Queue$.html","n":"Queue","t":"object Queue","d":"io/burkard/cdk/services/sqs/Queue$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/Queue$.html","n":"apply","t":"def apply(internalResourceId: String, fifoThroughputLimit: Option[FifoThroughputLimit], visibilityTimeout: Option[Duration], maxMessageSizeBytes: Option[Number], deliveryDelay: Option[Duration], encryption: Option[QueueEncryption], queueName: Option[String], fifo: Option[Boolean], retentionPeriod: Option[Duration], deadLetterQueue: Option[DeadLetterQueue], deduplicationScope: Option[DeduplicationScope], encryptionMasterKey: Option[IKey], receiveMessageWaitTime: Option[Duration], contentBasedDeduplication: Option[Boolean], removalPolicy: Option[RemovalPolicy], dataKeyReuse: Option[Duration])(implicit stackCtx: Stack): Queue","d":"io/burkard/cdk/services/sqs/Queue$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueAttributes$.html","n":"QueueAttributes","t":"object QueueAttributes","d":"io/burkard/cdk/services/sqs/QueueAttributes$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueAttributes$.html","n":"apply","t":"def apply(queueArn: String, queueUrl: Option[String], keyArn: Option[String], queueName: Option[String], fifo: Option[Boolean]): QueueAttributes","d":"io/burkard/cdk/services/sqs/QueueAttributes$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption.html","n":"QueueEncryption","t":"class QueueEncryption(val underlying: QueueEncryption) extends Product with Serializable","d":"io/burkard/cdk/services/sqs/QueueEncryption","k":"class"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption.html","n":"underlying","t":"val underlying: QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption","k":"val"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$.html","n":"QueueEncryption","t":"object QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$.html","n":"toAws","t":"def toAws(value: QueueEncryption): QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$$Kms$.html","n":"Kms","t":"object Kms extends QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$$Kms$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$$KmsManaged$.html","n":"KmsManaged","t":"object KmsManaged extends QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$$KmsManaged$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueEncryption$$Unencrypted$.html","n":"Unencrypted","t":"object Unencrypted extends QueueEncryption","d":"io/burkard/cdk/services/sqs/QueueEncryption$$Unencrypted$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicy$.html","n":"QueuePolicy","t":"object QueuePolicy","d":"io/burkard/cdk/services/sqs/QueuePolicy$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicy$.html","n":"apply","t":"def apply(internalResourceId: String, queues: List[_ <: IQueue])(implicit stackCtx: Stack): QueuePolicy","d":"io/burkard/cdk/services/sqs/QueuePolicy$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicyProps$.html","n":"QueuePolicyProps","t":"object QueuePolicyProps","d":"io/burkard/cdk/services/sqs/QueuePolicyProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueuePolicyProps$.html","n":"apply","t":"def apply(queues: List[_ <: IQueue]): QueuePolicyProps","d":"io/burkard/cdk/services/sqs/QueuePolicyProps$","k":"def"},
{"l":"io/burkard/cdk/services/sqs/QueueProps$.html","n":"QueueProps","t":"object QueueProps","d":"io/burkard/cdk/services/sqs/QueueProps$","k":"object"},
{"l":"io/burkard/cdk/services/sqs/QueueProps$.html","n":"apply","t":"def apply(fifoThroughputLimit: Option[FifoThroughputLimit], visibilityTimeout: Option[Duration], maxMessageSizeBytes: Option[Number], deliveryDelay: Option[Duration], encryption: Option[QueueEncryption], queueName: Option[String], fifo: Option[Boolean], retentionPeriod: Option[Duration], deadLetterQueue: Option[DeadLetterQueue], deduplicationScope: Option[DeduplicationScope], encryptionMasterKey: Option[IKey], receiveMessageWaitTime: Option[Duration], contentBasedDeduplication: Option[Boolean], removalPolicy: Option[RemovalPolicy], dataKeyReuse: Option[Duration]): QueueProps","d":"io/burkard/cdk/services/sqs/QueueProps$","k":"def"},
{"l":"docs/index.html","n":"sqs","t":"sqs","d":"","k":"static"}];
